[pango/small-caps: 9/11] Add PANGO_FONT_SCALE_PETITE_CAPS




commit 4785a434bf96da57a5c455e0f0c3731759ad3188
Author: Matthias Clasen <mclasen redhat com>
Date:   Sat Nov 6 23:25:24 2021 -0400

    Add PANGO_FONT_SCALE_PETITE_CAPS
    
    This will be used in the implementation of emulated
    Petite Caps.

 pango/pango-attributes.h | 4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)
---
diff --git a/pango/pango-attributes.h b/pango/pango-attributes.h
index 018417d5..95c20a6e 100644
--- a/pango/pango-attributes.h
+++ b/pango/pango-attributes.h
@@ -254,9 +254,10 @@ typedef enum {
  * @PANGO_FONT_SCALE_SUPERSCRIPT: Change the font to a size suitable for superscripts
  * @PANGO_FONT_SCALE_SUBSCRIPT: Change the font to a size suitable for subscripts
  * @PANGO_FONT_SCALE_SMALL_CAPS: Change the font to a size suitable for Small Caps. Since: 1.50
+ * @PANGO_FONT_SCALE_PETITE_CAPS: Change the font to a size suitable for Petite Caps. Since: 1.50
  *
  * An enumeration that affects font sizes for superscript
  * and subscript positioning and for (emulated) Small Caps.
  *
  * Since: 1.50
  */
@@ -265,6 +266,7 @@ typedef enum {
   PANGO_FONT_SCALE_SUPERSCRIPT,
   PANGO_FONT_SCALE_SUBSCRIPT,
   PANGO_FONT_SCALE_SMALL_CAPS,
+  PANGO_FONT_SCALE_PETITE_CAPS,
 } PangoFontScale;
 
 /**
@@ -254,9 +254,10 @@ typedef enum {
  *
  * An enumeration that affects font sizes for superscript
- * and subscript positioning and for (emulated) Small Caps.
+ * and subscript positioning and for (emulated) Small and Petite Caps.
  *
  * Since: 1.50


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]